(function(t,e){typeof exports=="object"&&typeof module<"u"?e(exports,require("vue"),require("@ose/js-core")):typeof define=="function"&&define.amd?define(["exports","vue","@ose/js-core"],e):(t=typeof globalThis<"u"?globalThis:t||self,e(t.ose_plugin_addicto={},t.Vue,t.OseJsCore))})(this,(function(t,e,i){"use strict";const s={class:"alert alert-danger"},r={key:1},a={key:2},d=e.defineComponent({__name:"AddictOVocab",props:{data:{},release:{},selectedSubStep:{}},emits:["release-control"],setup(n){return(c,l)=>(e.openBlock(),e.createElementBlock(e.Fragment,null,[l[1]||(l[1]=e.createElementVNode("h3",null,"Publishing the release",-1)),n.release.state==="waiting-for-user"&&n.data?.errors?.length>0?(e.openBlock(!0),e.createElementBlock(e.Fragment,{key:0},e.renderList(n.data.errors,o=>(e.openBlock(),e.createElementBlock("div",s,[o.details&&o?.response?.["hydra:description"]?(e.openBlock(),e.createElementBlock(e.Fragment,{key:0},[e.createElementVNode("h4",null,e.toDisplayString(o.response["hydra:title"]),1),e.createElementVNode("p",null,e.toDisplayString(o.details),1),e.createElementVNode("p",null,e.toDisplayString(o.response["hydra:description"]),1)],64)):(e.openBlock(),e.createElementBlock("pre",r,e.toDisplayString(JSON.stringify(o,void 0,2)),1))]))),256)):(e.openBlock(),e.createBlock(e.unref(i.ProgressIndicator),{key:1,details:n.data,release:n.release},{default:e.withCtx(()=>[...l[0]||(l[0]=[e.createElementVNode("p",null,[e.createTextVNode(" The ontologies are being published to AddictOVocab. This will take a while."),e.createElementVNode("br")],-1)])]),_:1},8,["details","release"])),n.release.state==="completed"?(e.openBlock(),e.createElementBlock("p",a," The ontologies were published to AddictOVocab. ")):e.createCommentVNode("",!0)],64))}});t.AddictOVocab=d,Object.defineProperty(t,Symbol.toStringTag,{value:"Module"})}));
